[dts][PATCH V1] tests/ice_limit_value_test: modify for 2 ports card sync with testplan

Lingli Chen linglix.chen at intel.com
Fri Jan 13 03:41:09 CET 2023


1 pf and 2 vfs can create 15360 rules at most on 2 ports card.

Signed-off-by: Lingli Chen <linglix.chen at intel.com>
---
 tests/TestSuite_ice_limit_value_test.py | 20 ++++++++++++++------
 1 file changed, 14 insertions(+), 6 deletions(-)

diff --git a/tests/TestSuite_ice_limit_value_test.py b/tests/TestSuite_ice_limit_value_test.py
index d6f2f969..7901a796 100644
--- a/tests/TestSuite_ice_limit_value_test.py
+++ b/tests/TestSuite_ice_limit_value_test.py
@@ -646,7 +646,7 @@ class TestICELimitValue(TestCase):
         """
         2*100G NIC, each pf can create 1024 rules at least, vfs share 14336 rules table
         4*25G NIC, each pf can create 512 rules at least, vfs share 14336 rules table
-        so if 2*25G NIC, max number is 14848 on 1pf and 2vfs.
+        so if 2*25G NIC, max number is (1024 + 14336) = 15360 on 1pf and 2vfs.
         if hardware is chapman beach 100g*2, 1 pf can create 2048 rules,vfs generated by the same pf share 14336 rules,
         so this card can create (2048 + 14336)*2=32768 rules
         """
@@ -656,11 +656,15 @@ class TestICELimitValue(TestCase):
         self.session_secondary = self.dut.new_session()
         # create kernel rules on pf1
         rule = "ethtool -N {} flow-type tcp4 src-ip 192.168.{}.{} dst-ip 192.168.100.2 src-port 32 dst-port 33 action 8 \n"
-        if self.nic in ["ICE_100G-E810C_QSFP"]:
+        if self.nic in [
+            "ICE_100G-E810C_QSFP",
+            "ICE_25G-E810_XXV_SFP",
+            "ICE_25G-E823C_QSFP",
+        ]:
             num = 4
             if self.is_chapman:
                 num = 8
-        if self.nic in ["ICE_25G-E810C_SFP", "ICE_25G-E810_XXV_SFP"]:
+        if self.nic in ["ICE_25G-E810C_SFP"]:
             num = 2
         for i in range(num):
             for j in range(256):
@@ -826,7 +830,7 @@ class TestICELimitValue(TestCase):
         """
         2*100G NIC, each pf can create 1024 rules at least, vfs share 14336 rules table
         4*25G NIC, each pf can create 512 rules at least, vfs share 14336 rules table
         so if 2*25G NIC, max number is 14848 on 1pf and vfs.
         create 15360/14848 rules on pf1, check failed to create rule on vf00 and vf10
         if hardware is chapman beach 100g*2, 1 pf can create 2048 rules,vfs generated by the same pf share 14336 rules,
         so if create 14386 rules on pf1,check failed to create rule on vf00 and vf10(vf00 and vf10 generated by pf1)
@@ -842,7 +846,11 @@ class TestICELimitValue(TestCase):
         num = 60
         if self.is_chapman:
             num = 64
-        if self.nic in ["ICE_100G-E810C_QSFP"]:
+        if self.nic in [
+            "ICE_100G-E810C_QSFP",
+            "ICE_25G-E810_XXV_SFP",
+            "ICE_25G-E823C_QSFP",
+        ]:
             for i in range(num):
                 for j in range(256):
                     flows.write(
@@ -855,7 +863,7 @@ class TestICELimitValue(TestCase):
                 count == num * 256,
                 "failed to create %s fdir rules on pf." % (num * 256),
             )
-        elif self.nic in ["ICE_25G-E810C_SFP", "ICE_25G-E810_XXV_SFP"]:
+        elif self.nic in ["ICE_25G-E810C_SFP"]:
             for i in range(58):
                 for j in range(256):
                     flows.write(
@@ -826,7 +830,7 @@ class TestICELimitValue(TestCase):
         2*100G NIC, each pf can create 1024 rules at least, vfs share 14336 rules table
         4*25G NIC, each pf can create 512 rules at least, vfs share 14336 rules table
-        so if 2*25G NIC, max number is 14848 on 1pf and vfs.
+        so if 2*25G NIC, max number is 15360 on 1pf and vfs.
         create 15360/14848 rules on pf1, check failed to create rule on vf00 and vf10
         if hardware is chapman beach 100g*2, 1 pf can create 2048 rules,vfs generated by the same pf share 14336 rules,
-- 
2.17.1



More information about the dts mailing list